==> plasma-framework_5.92.0.orig.tar.xz: plasma-framework-5.92.0/src/desktoptheme/air/metadata.desktop.cmake <==
[Desktop Entry]
Name=Air
Name[ar]=هواء
Name[az]=Air
Name[bs]=Vazduh
Name[ca]=Air
Name[ca@valencia]=Air
Name[cs]=Vzduch
Name[da]=Air
Name[de]=Air
Name[en_GB]=Air
Name[es]=Aire
Name[et]=Õhk
Name[eu]=Air
Name[fi]=Air
Name[fr]=Air
Name[gd]=Adhair
Name[gl]=Air
Name[hu]=Levegő
Name[ia]=Air
Name[id]=Air
Name[it]=Aria
Name[ko]=공기
Name[lt]=Oras
Name[lv]=Gaiss
Name[mr]=एअर
Name[nb]=Luft
Name[nds]=Luft
Name[nl]=Air
Name[nn]=Luft
Name[pa]=ਏਅਰ
Name[pl]=Powietrze
Name[pt]=Air
Name[pt_BR]=Air
Name[ro]=Aer
Name[ru]=Air
Name[sk]=Vzduch
Name[sl]=Zrak
Name[sr]=Ваздух
Name[sr@ijekavian]=Ваздух
Name[sr@ijekavianlatin]=Vazduh
Name[sr@latin]=Vazduh
Name[sv]=Luft
Name[tg]=Ҳаво
Name[tr]=Hava
Name[ug]=ھاۋا
Name[uk]=Air
Name[vi]=Air
Name[x-test]=xxAirxx
Name[zh_CN]=Air 净空
Name[zh_TW]=Air
Comment=A breath of fresh air
Comment[ar]=نسمة من الهواء المنعش
Comment[az]=Bir nəfəs təmiz hava
Comment[bs]=Dašak svježeg vazduha
Comment[ca]=Una alenada d'aire fresc
Comment[ca@valencia]=Una alenada d'aire fresc
Comment[cs]=Závan čerstvého vzduchu
Comment[da]=En mundfuld frisk luft
Comment[de]=Ein Atemzug frische Luft
Comment[en_GB]=A breath of fresh air
Comment[es]=Una bocanada de aire fresco
Comment[et]=Värskendav tuulepuhang
Comment[eu]=Haize berria
Comment[fi]=Raikkaan ilman leyhähdys
Comment[fr]=Un souffle d'air frais
Comment[gd]=Anail
Comment[gl]=Un folgo de ar fresco
Comment[hu]=Friss fuvallat
Comment[ia]=Un respiration de aere fresc
Comment[id]=Sebuah hirupan udara yang segar
Comment[it]=Una ventata di aria fresca
Comment[ko]=신선한 바람
Comment[lt]=Gryno oro gurkšnis
Comment[lv]=Svaiga gaisa malks
Comment[mr]=शुद्ध हवेचा श्वास
Comment[nb]=Et pust av frisk luft
Comment[nds]=Wat frische Luft
Comment[nl]=Een hap frisse lucht
Comment[nn]=Eit friskt pust
Comment[pa]=ਤਾਜ਼ਾ ਹਵਾ ਵਿੱਚ ਸਾਹ ਲਵੋ
Comment[pl]=Powiew świeżego powietrza
Comment[pt]=Uma brisa de ar fresco
Comment[pt_BR]=Um pouco de ar fresco
Comment[ro]=O gură de aer proaspăt
Comment[ru]=Волшебные пузырьки
Comment[sk]=Závan čerstvého vzduchu
Comment[sl]=Svež vetrič
Comment[sr]=Дашак свежег ваздуха
Comment[sr@ijekavian]=Дашак свјежег ваздуха
Comment[sr@ijekavianlatin]=Dašak svježeg vazduha
Comment[sr@latin]=Dašak svežeg vazduha
Comment[sv]=Ett friskt andetag
Comment[tg]=Нафаскашии ҳавои тоза
Comment[tr]=Temiz havadan bir nefes
Comment[ug]=ساپ ھاۋادىن نەپەسلىنىش
Comment[uk]=Ковток свіжого повітря
Comment[vi]=Một luồng không khí trong lành
Comment[x-test]=xxA breath of fresh airxx
Comment[zh_CN]=如清新空气般淡雅的主题
Comment[zh_TW]=吸一口新鮮空氣


X-KDE-PluginInfo-Author=The Oxygen Project
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=air
X-KDE-PluginInfo-Version=@KF_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Elarun
defaultFileSuffix=.png
defaultWidth=2560
defaultHeight=1600

[ContrastEffect]
enabled=true
contrast=0.3
intensity=1.9
saturation=1.9

==> plasma-framework-5.93.0.tar.xz: plasma-framework-5.93.0/src/desktoptheme/air/metadata.desktop.cmake <==
[Desktop Entry]
Name=Air
Name[ar]=هواء
Name[az]=Air
Name[bs]=Vazduh
Name[ca]=Air
Name[ca@valencia]=Air
Name[cs]=Vzduch
Name[da]=Air
Name[de]=Air
Name[en_GB]=Air
Name[es]=Aire
Name[et]=Õhk
Name[eu]=Air
Name[fi]=Air
Name[fr]=Air
Name[gd]=Adhair
Name[gl]=Air
Name[hu]=Levegő
Name[ia]=Air
Name[id]=Air
Name[it]=Aria
Name[ko]=공기
Name[lt]=Oras
Name[lv]=Gaiss
Name[mr]=एअर
Name[nb]=Luft
Name[nds]=Luft
Name[nl]=Air
Name[nn]=Luft
Name[pa]=ਏਅਰ
Name[pl]=Powietrze
Name[pt]=Air
Name[pt_BR]=Air
Name[ro]=Aer
Name[ru]=Air
Name[sk]=Vzduch
Name[sl]=Zrak
Name[sr]=Ваздух
Name[sr@ijekavian]=Ваздух
Name[sr@ijekavianlatin]=Vazduh
Name[sr@latin]=Vazduh
Name[sv]=Luft
Name[tg]=Ҳаво
Name[tr]=Hava
Name[ug]=ھاۋا
Name[uk]=Air
Name[vi]=Air
Name[x-test]=xxAirxx
Name[zh_CN]=Air 净空
Name[zh_TW]=Air
Comment=A breath of fresh air
Comment[ar]=نسمة من الهواء المنعش
Comment[az]=Bir nəfəs təmiz hava
Comment[bs]=Dašak svježeg vazduha
Comment[ca]=Una alenada d'aire fresc
Comment[ca@valencia]=Una alenada d'aire fresc
Comment[cs]=Závan čerstvého vzduchu
Comment[da]=En mundfuld frisk luft
Comment[de]=Ein Atemzug frische Luft
Comment[en_GB]=A breath of fresh air
Comment[es]=Una bocanada de aire fresco
Comment[et]=Värskendav tuulepuhang
Comment[eu]=Haize berria
Comment[fi]=Raikkaan ilman leyhähdys
Comment[fr]=Un souffle d'air frais
Comment[gd]=Anail
Comment[gl]=Un folgo de ar fresco
Comment[hu]=Friss fuvallat
Comment[ia]=Un respiration de aere fresc
Comment[id]=Sebuah hirupan udara yang segar
Comment[it]=Una ventata di aria fresca
Comment[ko]=신선한 바람
Comment[lt]=Gryno oro gurkšnis
Comment[lv]=Svaiga gaisa malks
Comment[mr]=शुद्ध हवेचा श्वास
Comment[nb]=Et pust av frisk luft
Comment[nds]=Wat frische Luft
Comment[nl]=Een hap frisse lucht
Comment[nn]=Eit friskt pust
Comment[pa]=ਤਾਜ਼ਾ ਹਵਾ ਵਿੱਚ ਸਾਹ ਲਵੋ
Comment[pl]=Powiew świeżego powietrza
Comment[pt]=Uma brisa de ar fresco
Comment[pt_BR]=Um pouco de ar fresco
Comment[ro]=O gură de aer proaspăt
Comment[ru]=Волшебные пузырьки
Comment[sk]=Závan čerstvého vzduchu
Comment[sl]=Svež vetrič
Comment[sr]=Дашак свежег ваздуха
Comment[sr@ijekavian]=Дашак свјежег ваздуха
Comment[sr@ijekavianlatin]=Dašak svježeg vazduha
Comment[sr@latin]=Dašak svežeg vazduha
Comment[sv]=Ett friskt andetag
Comment[tg]=Нафаскашии ҳавои тоза
Comment[tr]=Temiz hava soluğu
Comment[ug]=ساپ ھاۋادىن نەپەسلىنىش
Comment[uk]=Ковток свіжого повітря
Comment[vi]=Một luồng không khí trong lành
Comment[x-test]=xxA breath of fresh airxx
Comment[zh_CN]=如清新空气般淡雅的主题
Comment[zh_TW]=吸一口新鮮空氣


X-KDE-PluginInfo-Author=The Oxygen Project
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=air
X-KDE-PluginInfo-Version=@KF_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Elarun
defaultFileSuffix=.png
defaultWidth=2560
defaultHeight=1600

[ContrastEffect]
enabled=true
contrast=0.3
intensity=1.9
saturation=1.9
